Accepting request 36900 from X11:Utilities

Copy from X11:Utilities/xli based on submit request 36900 from user oertel

OBS-URL: https://build.opensuse.org/request/show/36900
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/xli?expand=0&rev=8
This commit is contained in:
OBS User autobuild 2010-04-04 18:09:22 +00:00 committed by Git OBS Bridge
parent 26cf1cdef4
commit ec7fb21df1
3 changed files with 30 additions and 57 deletions

20
xli-png_check_sig.patch Normal file
View File

@ -0,0 +1,20 @@
--- png.c
+++ png.c
@@ -11,7 +11,7 @@
#define TITLE_KEYWORD "Title"
/* check to see if a file is a png file using png_check_sig() */
static int check_png(char *file_name)
{
ZFILE *zfp;
@@ -27,7 +27,7 @@
if (ret != 8)
return 0;
- ret = png_check_sig(buf, 8);
+ ret = !png_sig_cmp(buf, 0, 8);
return (ret);
}

View File

@ -1,3 +1,8 @@
-------------------------------------------------------------------
Sun Apr 4 18:51:25 CEST 2010 - ro@suse.de
- fix build with libpng14
-------------------------------------------------------------------
Fri Apr 13 17:18:59 CEST 2007 - lmichnovic@suse.cz

View File

@ -1,7 +1,7 @@
#
# spec file for package xli (Version 20061110)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
@ -20,12 +20,12 @@
Name: xli
BuildRequires: libjpeg-devel libpng-devel xorg-x11-devel
%define ver 2005-09-04
License: X11/MIT
License: MIT
Group: System/X11/Utilities
Provides: xli115
AutoReqProv: on
Version: 20061110
Release: 125
Release: 126
Summary: X11 Image Loading Utility
Url: http://pantransit.reptiles.org/prog
Source: xli-2006-11-10.tar.bz2
@ -33,6 +33,7 @@ Patch0: xli-1.17.0.patch
Patch1: xli-1.17.0-overflow.patch
Patch2: xli-1.17.0-8bit_palette.patch
Patch3: xli-1.17.0-configfile.patch
Patch4: xli-png_check_sig.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-build
%if "%(xft-config --prefix)" == "/usr"
%define _xorg7libs %_lib
@ -81,6 +82,7 @@ Authors:
%patch1
%patch2
%patch3
%patch4
%build
xmkmf -a
@ -106,57 +108,3 @@ rm -rf $RPM_BUILD_ROOT
/usr/lib/X11/Xli
%changelog
* Fri Apr 13 2007 lmichnovic@suse.cz
- update to new snapshot 2006/11/10
* fixing a crash on PGM/PPM images with a maxval > 255,
and various warnings about uninitialized variables.
* Fri Feb 09 2007 aj@suse.de
- Add defattr.
* Thu Jul 27 2006 lmichnovic@suse.cz
- building with X.org 7.x: detects version of X.org instead of
suse_version
* Sat Jul 22 2006 lmichnovic@suse.cz
- create config file in /usr/lib/X11/Xli as sugested in man page
(configfile.patch)
- now builds also with new X.org 7.x
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 lmichnovic@suse.cz
- added -fstack-protector into CCOPTIONS in specfile
* Fri Oct 14 2005 lmichnovic@suse.cz
- fixed buffer overflow which can be misused to execute arbitrary code (#121922)
- added support 8bit color images with palette.
* Thu Sep 08 2005 ltinkl@suse.cz
- update to snapshot 2005-09-04 which incorporates fixes for
the previous security bug (#66139) and fullscreen handling
(#115258)
* Fri Jun 10 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Wed Apr 20 2005 ltinkl@suse.de
- fix buffer overflow (#66139)
* Thu Jul 01 2004 bg@suse.de
- fix Imakefile for hppa
* Tue Feb 24 2004 schwab@suse.de
- Fix bad unsigned division [#25778].
* Wed Jun 04 2003 mjancar@suse.cz
- added URL
* Wed Nov 13 2002 jderfina@suse.cz
- fixed "GCC no longer implements <varargs.h>." error.
* Thu Sep 26 2002 max@suse.de
- New version 1.17.0.
- Now supports PNG and progressive JPEG.
* Tue Sep 04 2001 nadvornik@suse.cz
- fixed copyright tag
- removed Provides: xli
* Fri Jul 20 2001 nadvornik@suse.cz
- fixed possible buffer overflow
* Fri Apr 13 2001 schwab@suse.de
- Fix missing declarations.
- Fix unaligned access.
* Fri May 12 2000 nadvornik@suse.cz
- added BuildRoot
- removed Makefile.Linux
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jun 09 1997 fehr@suse.de
- make all smlinks relative
@@ -11,7 +11,7 @@
#define TITLE_KEYWORD "Title"
-/* check to see if a file is a png file using png_check_sig() */
+/* check to see if a file is a png file using png_sig_cmp() */
static int check_png(char *file_name)
{